mocks

package
v3.4.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 6, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	mock.Mock
}

Client is an autogenerated mock type for the Client type

func NewClient

func NewClient(t interface {
	mock.TestingT
	Cleanup(func())
}) *Client

NewClient creates a new instance of Client. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*Client) CleanChartCache

func (_mock *Client) CleanChartCache(chart string, version string) error

CleanChartCache provides a mock function for the type Client

func (*Client) EXPECT added in v3.1.0

func (_m *Client) EXPECT() *Client_Expecter

func (*Client) ExtractChart

func (_mock *Client) ExtractChart(chart string, version string, passCredentials bool, manifestMaxExtractedSize int64, disableManifestMaxExtractedSize bool) (string, io.Closer, error)

ExtractChart provides a mock function for the type Client

func (*Client) GetIndex

func (_mock *Client) GetIndex(noCache bool, maxIndexSize int64) (*helm.Index, error)

GetIndex provides a mock function for the type Client

func (*Client) GetTags

func (_mock *Client) GetTags(chart string, noCache bool) ([]string, error)

GetTags provides a mock function for the type Client

func (*Client) TestHelmOCI

func (_mock *Client) TestHelmOCI() (bool, error)

TestHelmOCI provides a mock function for the type Client

type Client_CleanChartCache_Call added in v3.1.0

type Client_CleanChartCache_Call struct {
	*mock.Call
}

Client_CleanChartCache_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'CleanChartCache'

func (*Client_CleanChartCache_Call) Return added in v3.1.0

func (*Client_CleanChartCache_Call) Run added in v3.1.0

func (_c *Client_CleanChartCache_Call) Run(run func(chart string, version string)) *Client_CleanChartCache_Call

func (*Client_CleanChartCache_Call) RunAndReturn added in v3.1.0

func (_c *Client_CleanChartCache_Call) RunAndReturn(run func(chart string, version string) error) *Client_CleanChartCache_Call

type Client_Expecter added in v3.1.0

type Client_Expecter struct {
	// contains filtered or unexported fields
}

func (*Client_Expecter) CleanChartCache added in v3.1.0

func (_e *Client_Expecter) CleanChartCache(chart interface{}, version interface{}) *Client_CleanChartCache_Call

CleanChartCache is a helper method to define mock.On call

  • chart string
  • version string

func (*Client_Expecter) ExtractChart added in v3.1.0

func (_e *Client_Expecter) ExtractChart(chart interface{}, version interface{}, passCredentials interface{}, manifestMaxExtractedSize interface{}, disableManifestMaxExtractedSize interface{}) *Client_ExtractChart_Call

ExtractChart is a helper method to define mock.On call

  • chart string
  • version string
  • passCredentials bool
  • manifestMaxExtractedSize int64
  • disableManifestMaxExtractedSize bool

func (*Client_Expecter) GetIndex added in v3.1.0

func (_e *Client_Expecter) GetIndex(noCache interface{}, maxIndexSize interface{}) *Client_GetIndex_Call

GetIndex is a helper method to define mock.On call

  • noCache bool
  • maxIndexSize int64

func (*Client_Expecter) GetTags added in v3.1.0

func (_e *Client_Expecter) GetTags(chart interface{}, noCache interface{}) *Client_GetTags_Call

GetTags is a helper method to define mock.On call

  • chart string
  • noCache bool

func (*Client_Expecter) TestHelmOCI added in v3.1.0

func (_e *Client_Expecter) TestHelmOCI() *Client_TestHelmOCI_Call

TestHelmOCI is a helper method to define mock.On call

type Client_ExtractChart_Call added in v3.1.0

type Client_ExtractChart_Call struct {
	*mock.Call
}

Client_ExtractChart_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ExtractChart'

func (*Client_ExtractChart_Call) Return added in v3.1.0

func (*Client_ExtractChart_Call) Run added in v3.1.0

func (_c *Client_ExtractChart_Call) Run(run func(chart string, version string, passCredentials bool, manifestMaxExtractedSize int64, disableManifestMaxExtractedSize bool)) *Client_ExtractChart_Call

func (*Client_ExtractChart_Call) RunAndReturn added in v3.1.0

func (_c *Client_ExtractChart_Call) RunAndReturn(run func(chart string, version string, passCredentials bool, manifestMaxExtractedSize int64, disableManifestMaxExtractedSize bool) (string, io.Closer, error)) *Client_ExtractChart_Call

type Client_GetIndex_Call added in v3.1.0

type Client_GetIndex_Call struct {
	*mock.Call
}

Client_GetIndex_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetIndex'

func (*Client_GetIndex_Call) Return added in v3.1.0

func (_c *Client_GetIndex_Call) Return(index *helm.Index, err error) *Client_GetIndex_Call

func (*Client_GetIndex_Call) Run added in v3.1.0

func (_c *Client_GetIndex_Call) Run(run func(noCache bool, maxIndexSize int64)) *Client_GetIndex_Call

func (*Client_GetIndex_Call) RunAndReturn added in v3.1.0

func (_c *Client_GetIndex_Call) RunAndReturn(run func(noCache bool, maxIndexSize int64) (*helm.Index, error)) *Client_GetIndex_Call

type Client_GetTags_Call added in v3.1.0

type Client_GetTags_Call struct {
	*mock.Call
}

Client_GetTags_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetTags'

func (*Client_GetTags_Call) Return added in v3.1.0

func (_c *Client_GetTags_Call) Return(strings []string, err error) *Client_GetTags_Call

func (*Client_GetTags_Call) Run added in v3.1.0

func (_c *Client_GetTags_Call) Run(run func(chart string, noCache bool)) *Client_GetTags_Call

func (*Client_GetTags_Call) RunAndReturn added in v3.1.0

func (_c *Client_GetTags_Call) RunAndReturn(run func(chart string, noCache bool) ([]string, error)) *Client_GetTags_Call

type Client_TestHelmOCI_Call added in v3.1.0

type Client_TestHelmOCI_Call struct {
	*mock.Call
}

Client_TestHelmOCI_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'TestHelmOCI'

func (*Client_TestHelmOCI_Call) Return added in v3.1.0

func (*Client_TestHelmOCI_Call) Run added in v3.1.0

func (_c *Client_TestHelmOCI_Call) Run(run func()) *Client_TestHelmOCI_Call

func (*Client_TestHelmOCI_Call) RunAndReturn added in v3.1.0

func (_c *Client_TestHelmOCI_Call) RunAndReturn(run func() (bool, error)) *Client_TestHelmOCI_Call

Jump to